@@ -67,7 +67,7 @@ class SortedDataNode(template.Node):
         self.null_ordering = null_ordering
 
     def render(self, context: Context) -> str:
-        key = self.context_var if self.context_var is not None else self.queryset_var.var
+        key: str = self.context_var if self.context_var is not None else str(self.queryset_var.var)
 
         queryset = self.queryset_var.resolve(context)
         order_by = common.get_order_by_from_request(context["request"])
@@ -116,7 +116,9 @@ def anchor(parser: Parser, token: Token) -> SortAnchorNode:
     except IndexError:
         title = bits[1].capitalize()
 
-    default_sort_order = "desc" if len(bits) >= 4 and bits[3].strip("'\"") == "desc" else "asc"
+    default_sort_order: Literal["asc", "desc"] = (
+        "desc" if len(bits) >= 4 and bits[3].strip("'\"") == "desc" else "asc"
+    )
 
     return SortAnchorNode(
         bits[1].strip(),
